#!/usr/bin/perl

#####################################################
#
# Program: MetaPyler Version 1.13
#
#          Estimate bacterial composition from
#          metagenomic sequences. 
#          
#
# Contact: Bo Liu, boliu@umiacs.umd.edu
#
# Last Update: Mon Mar 14 15:14:49 EDT 2011
#
#####################################################

use strict;
use warnings;


#---------------------------------------------------#
# read command line parameters
#---------------------------------------------------#
my $fnafile = "";       # input blastx file
my $prefix = "";          # output files prefix
if (scalar @ARGV == 2) {
    $fnafile = $ARGV[0];
    $prefix = $ARGV[1];
} else {
    Usage();
}
#---------------------------------------------------#


my $cmd = "";
$cmd = "./blastref.pl $fnafile > $prefix.blastn";
system($cmd);

$cmd = "./metaphyler.pl $prefix.blastn $prefix";
system($cmd);



exit;


sub Usage {
    die("
USAGE:
       ./metaphylerAll.pl <fasta file> <Output prefix>

INPUT:
       Output prefix:
           6 output files will be generated:\"prefix\".classify.tab,
           \"prefix\".genus.tab, \"prefix\".family.tab,
           \"prefix\".order.tab, \"prefix\".class.tab, \"prefix\".phylum.tab
OUTPUT:
       \"prefix\".classify.tab
           column 1: query sequence id
           column 2: phylogenetic marker gene name
           column 3: best reference gene hit
           column 4: % similarity with best hit
           column 5: classification rule
           column 6: taxonomic label at genus level
           column 7: taxonomic label at family level
           column 8: taxonomic label at order level
           column 9: taxonomic label at class level
           column 10: taxonomic label at phylum level

       \"prefix\".genus|family|order|class|phylum.tab
           column 1: taxonomic clade name
           column 2: % relative abundances
           column 3: depth of coverage of genomes
           column 4: number of sequences binned to this clade
           column 5: similarity with reference genes (only available at the genus level)

NOTES:
       1, Here we assume the query sequences have been BLASTNed against the
          reference marker genes, which is used as the input of this program.
          To run MetaPhyler directly for a set of query sequences, use program
          metaphylerall.pl

EXAMPLE:
       ./metaphylerAll.pl ./test/test.fna test

");
}
